==> afs_autotests-1.0.tar.gz: afs_autotests-1.0/afs_autotests/afs_base_objects/base_elements.py <==
from typing import Union
from afs_autotests.exceptions import ParameterNotFoundException


class _AFSBaseElement(object):
    """

    Базовый элемент

    Attributes:
        data: Данные элемента
    """
    _parameters = {}
    _id = None

    def __init__(self, data=None):
        """Инциализация _AFSBaseElement"""
        if data:
            self.init(data)

    def init(self, data: dict):
        """Метод инициализации"""
        self._parameters = data['parameters']
        self._id = int(data['id'])

    def get_id(self) -> int:
        """Получить ID элемента"""
        return self._id

    def find_parameter(self, parameter_name) -> Union[int, str, bool, None]:
        """Найти параметр элемента"""
        if parameter_name in self._parameters.keys():
            return self._parameters[parameter_name]
        return None


class AFSTestProject(_AFSBaseElement):
    """

    Элемент TestProject.

    Attributes:
        data: Данные элемента
    """

    _default_url = None
    _name = None

    def __init__(self, data=None):
        """Инциализация AFSTestProject"""
        super().__init__(data=data)

    def init(self, data: dict):
        """Метод инициализации"""
        super().init(data=data)

        self._default_url = data['default_url']
        self._name = data['name']

    @property
    def default_url(self) -> str:
        """Получить адресс страницы по умолчанию"""
        return self._default_url

    @property
    def name(self) -> str:
        """Получить имя проекта"""
        return self._name


class AFSTestRun(_AFSBaseElement):
    """

    Элемент TestRun.

    Attributes:
        data: Данные элемента
    """

    _suites = {}
    _status_str = None
    _status_id = None

    def __init__(self, data=None):
        """Инциализация AFSTestRun"""
        super().__init__(data=data)

    def init(self, data):
        """Метод инициализации"""
        super().init(data)
        self._status_id = data['status_id']
        self._status_str = data['status_str']

    @property
    def status_id(self) -> int:
        """Получить статус ID TestRun"""
        return self._status_id

    @property
    def string_status(self) -> str:
        """Получить тестовый статус TestRun"""
        return self._status_str

    def find_suite_by_id(self, suite_id) -> AFSTestSuite:
        """Найти TestSuite по ID"""
        if int(suite_id) in self._suites.keys():
            return self._suites[suite_id]

    def find_suite_by_name(self, suite_name) -> Union[AFSTestSuite, None]:
        """Найти TestSuite по имени"""
        for item in self._suites.keys():
            if self._suites[item] == suite_name:
                return self._suites[item]
        else:
            return None


class AFSTestSuite(_AFSBaseElement):
    """

    Элемент TestSuite.

    Attributes:
        data: Данные элемента
    """

    _testcases = {}
    _project_id = None
    _project_name = None
    _file = None
    _name = None
    _short_description = None

    def __init__(self, data=None):
        """Инциализация AFSTestSuite"""
        super().__init__(data=data)

    def init(self, data: dict):
        """Метод инициализации"""
        super().init(data)

        self._project_id = data['project_id']
        self._project_name = data['project_name']
        self._file = data['file']
        self._name = data['file']
        self._short_description = data['_short_description']

        if 'testcases' in data.keys():
            for item in data['testcases'].keys():
                self._testcases.update({int(item): data['testcases'][item]})

    @property
    def name(self) -> str:
        """Получить имя TestSuite"""
        return self._file

    @property
    def file_name(self) -> str:
        """Получить имя файла"""
        return self._file

    @property
    def short_description(self) -> str:
        """Получить короткое описание TestSuite"""
        return self._short_description

    @property
    def project_id(self) -> int:
        """Получить ID проекта к которому относится TestSuite"""
        return self._project_id

    @property
    def project_name(self) -> str:
        """Получить имя проекта к которому относится TestSuite"""
        return self._project_name

    def find_testcase_by_name(self, testcase_name) -> AFSTestCase:
        """Найти TestCase по ID"""
        for item in self._testcases.keys():
            if testcase_name == self._testcases[item]:
                return item

    def find_testcase_by_id(self, testcase_id) -> AFSTestCase:
        """Найти TestCase по имени"""
        if int(testcase_id) in self._testcases.keys():
            return self._testcases[testcase_id]


class AFSTestCase(_AFSBaseElement):
    """

    Элемент TestCase.

    Attributes:
        data: Данные элемента
    """

    _data = {}
    _name = None
    _description = None
    _short_description = None

    def __init__(self, data=None):
        """Инциализация AFSTestSuite"""
        super().__init__(data=data)

    def init(self, data):
        """Метод инициализации"""
        super().init(data)
        self._name = data['name']

        if 'data' in data.keys():
            self._data = data['data']

    @property
    def name(self) -> str:
        """Получить имя AFSTestCase"""
        return self._name

    def short_description(self) -> str:
        """Получить короткое описание TestCase"""
        return self._short_description

    @property
    def description(self) -> str:
        """Получить описание TestCase"""
        return self._description

    def find_data(self, name) -> Union[str, int, bool]:
        """Найти данные теста по имени"""
        if name in self._data.keys():
            return self._data['name']
        else:
            raise ParameterNotFoundException(
                "Parameter with name \"{0}\" not implemented in TestCase \"{1}\"".format(name, self.name))

==> afs_autotests-1.2.tar.gz: afs_autotests-1.2/afs_autotests/afs_base_objects/base_elements.py <==
from typing import Union
from afs_autotests.exceptions import ParameterNotFoundException


class _AFSBaseElement(object):
    """

    Базовый элемент

    Attributes:
        data: Данные элемента
    """
    _parameters = {}
    _id = None

    def __init__(self, data=None):
        """Инциализация _AFSBaseElement"""
        if data:
            self.init(data)

    def init(self, data: dict):
        """Метод инициализации"""
        self._parameters = data['parameters']
        self._id = int(data['id'])

    def get_id(self) -> int:
        """Получить ID элемента"""
        return self._id

    def find_parameter(self, parameter_name) -> Union[int, str, bool, None]:
        """Найти параметр элемента"""
        if parameter_name in self._parameters.keys():
            return self._parameters[parameter_name]
        return None


class AFSTestProject(_AFSBaseElement):
    """

    Элемент TestProject.

    Attributes:
        data: Данные элемента
    """

    _default_url = None
    _name = None

    def __init__(self, data=None):
        """Инциализация AFSTestProject"""
        super().__init__(data=data)

    def init(self, data: dict):
        """Метод инициализации"""
        super().init(data=data)

        self._default_url = data['default_url']
        self._name = data['name']

    @property
    def default_url(self) -> str:
        """Получить адресс страницы по умолчанию"""
        return self._default_url

    @property
    def name(self) -> str:
        """Получить имя проекта"""
        return self._name


class AFSTestCase(_AFSBaseElement):
    """

    Элемент TestCase.

    Attributes:
        data: Данные элемента
    """

    _data = {}
    _name = None
    _description = None
    _short_description = None

    def __init__(self, data=None):
        """Инциализация AFSTestSuite"""
        super().__init__(data=data)

    def init(self, data):
        """Метод инициализации"""
        super().init(data)
        self._name = data['name']
        self._description = data['description']
        self._short_description = data['short_description']

        if 'data' in data.keys():
            self._data = data['data']

    @property
    def name(self) -> str:
        """Получить имя AFSTestCase"""
        return self._name

    def short_description(self) -> str:
        """Получить короткое описание TestCase"""
        return self._short_description

    @property
    def description(self) -> str:
        """Получить описание TestCase"""
        return self._description

    def find_data(self, name) -> Union[str, int, bool]:
        """Найти данные теста по имени"""
        if name in self._data.keys():
            return self._data['name']
        else:
            raise ParameterNotFoundException(
                "Parameter with name \"{0}\" not implemented in TestCase \"{1}\"".format(name, self.name))


class AFSTestSuite(_AFSBaseElement):
    """

    Элемент TestSuite.

    Attributes:
        data: Данные элемента
    """

    _testcases = {}
    _project_id = None
    _project_name = None
    _file = None
    _name = None
    _short_description = None
    _description = None

    def __init__(self, data=None):
        """Инциализация AFSTestSuite"""
        super().__init__(data=data)

    def init(self, data: dict):
        """Метод инициализации"""
        super().init(data)

        self._project_id = data['project_id']
        self._project_name = data['project_name']
        self._file = data['file']
        self._name = data['file']
        self._short_description = data['short_description']

        if 'testcases' in data.keys():
            for item in data['testcases'].keys():
                self._testcases.update({int(item): data['testcases'][item]})

    @property
    def name(self) -> str:
        """Получить имя TestSuite"""
        return self._file

    @property
    def file_name(self) -> str:
        """Получить имя файла"""
        return self._file

    @property
    def short_description(self) -> str:
        """Получить короткое описание TestSuite"""
        return self._short_description

    @property
    def description(self) -> str:
        """Получить описание TestSuite"""
        return self._description

    @property
    def project_id(self) -> int:
        """Получить ID проекта к которому относится TestSuite"""
        return self._project_id

    @property
    def project_name(self) -> str:
        """Получить имя проекта к которому относится TestSuite"""
        return self._project_name

    def find_testcase_by_name(self, testcase_name) -> AFSTestCase:
        """Найти TestCase по ID"""
        for item in self._testcases.keys():
            if testcase_name == self._testcases[item]:
                return item

    def find_testcase_by_id(self, testcase_id) -> AFSTestCase:
        """Найти TestCase по имени"""
        if int(testcase_id) in self._testcases.keys():
            return self._testcases[testcase_id]


class AFSTestRun(_AFSBaseElement):
    """

    Элемент TestRun.

    Attributes:
        data: Данные элемента
    """

    _suites = {}
    _status_str = None
    _status_id = None

    def __init__(self, data=None):
        """Инциализация AFSTestRun"""
        super().__init__(data=data)

    def init(self, data):
        """Метод инициализации"""
        super().init(data)
        self._status_id = data['status_id']
        self._status_str = data['status_str']

    @property
    def status_id(self) -> int:
        """Получить статус ID TestRun"""
        return self._status_id

    @property
    def string_status(self) -> str:
        """Получить тестовый статус TestRun"""
        return self._status_str

    def find_suite_by_id(self, suite_id) -> AFSTestSuite:
        """Найти TestSuite по ID"""
        if int(suite_id) in self._suites.keys():
            return self._suites[suite_id]

    def find_suite_by_name(self, suite_name) -> Union[AFSTestSuite, None]:
        """Найти TestSuite по имени"""
        for item in self._suites.keys():
            if self._suites[item] == suite_name:
                return self._suites[item]
        else:
            return None
